#
# spec file for package eduvpn-client
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
%define vname linux-app
Name:           eduvpn-client
Version:        4.5.1
Release:        1.1
Summary:        The eduVPN desktop client (CLI and GUI front-end)
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Security
URL:            https://www.eduvpn.org/
Source0:        https://codeberg.org/eduVPN/linux-app/releases/download/%{version}/%{vname}-%{version}.tar.xz
Source1:        https://codeberg.org/eduVPN/linux-app/releases/download/%{version}/%{vname}-%{version}.tar.xz.asc
                # https://app.eduvpn.org/linux/v4/deb/app+linux@eduvpn.org.asc and inside package dir 'keys'
Source2:        %{name}.keyring
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module eduvpn-common >= 3.0.0 with %python-eduvpn-common < 4}
BuildRequires:  %{python_module gobject}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pycodestyle}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module selenium}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gtk3
BuildRequires:  libnotify
BuildRequires:  python-rpm-macros
BuildRequires:  rsync
BuildRequires:  update-desktop-files
Requires:       NetworkManager-openvpn
Requires:       gtk3
Requires:       python3-%{name}
BuildArch:      noarch
%define python_subpackage_only 1
%python_subpackages

%description
The eduVPN desktop client is a specialized virtual private network (VPN)
solution designed primarily for the education and research community. It offers
preconfigured secure and private network connections for students, faculty, and
researchers at educational institutions, providing several key advantages over
traditional VPN clients.

%package -n python-%{name}
Summary:        Python3 API for eduVPN
Requires:       NetworkManager-openvpn
Requires:       (python-eduvpn-common >= 3.0.0 with python-eduvpn-common < 4)
Requires:       python-gobject

%description -n python-%{name}
eduVPN client API for Python3

%package -n letsconnect-client
Summary:        Let's Connect! desktop client
Requires:       gtk3
Requires:       python3-%{name}

%description -n letsconnect-client
The 'Let's Connect!' desktop client is an open source VPN solution that enables
ISPs, hosters and companies to easily set up a secure VPN service. The project
is known under two names: 'Let’s Connect!' and eduVPN. The brand eduVPN is used
to promote this VPN solution to international educational and research
organizations.

%prep
%autosetup -n %{vname}-%{version}

# Dir 'data' conflicts otherwise with Python subpackages
mv eduvpn/data data

%build
%pyproject_wheel

%install
%pyproject_install

# Manual copy of extra files. Previously they were specified in setup.py.
rsync -a data/share/ \
  --exclude '*.po' \
  --exclude '*.pot' \
  --exclude 'Makefile' %{buildroot}%{_datadir}/

%find_lang eduVPN
%suse_update_desktop_file org.eduvpn.client Network Dialup
%suse_update_desktop_file org.letsconnect-vpn.client Network Dialup
%fdupes %{buildroot}%{_datadir}
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files -n %{name} -f eduVPN.lang
%license LICENSE
%doc CHANGES.md README.md
%dir %{_datadir}/eduvpn
%{_datadir}/eduvpn/
%{_bindir}/eduvpn-cli
%{_bindir}/eduvpn-gui
%{_datadir}/applications/org.eduvpn.client.desktop
%{_datadir}/icons/hicolor/128x128/apps/org.eduvpn.client.png
%{_datadir}/icons/hicolor/256x256/apps/org.eduvpn.client.png
%{_datadir}/icons/hicolor/48x48/apps/org.eduvpn.client.png
%{_datadir}/icons/hicolor/512x512/apps/org.eduvpn.client.png

%files %{python_files %{name}}
%license LICENSE
%doc CHANGES.md README.md
%{python_sitelib}/eduvpn*

%files -n letsconnect-client
%license LICENSE
%doc CHANGES.md README.md
%dir %{_datadir}/letsconnect
%{_datadir}/letsconnect/
%{_bindir}/letsconnect-cli
%{_bindir}/letsconnect-gui
%{_datadir}/applications/org.letsconnect-vpn.client.desktop
%{_datadir}/icons/hicolor/128x128/apps/org.letsconnect-vpn.client.png
%{_datadir}/icons/hicolor/256x256/apps/org.letsconnect-vpn.client.png
%{_datadir}/icons/hicolor/48x48/apps/org.letsconnect-vpn.client.png
%{_datadir}/icons/hicolor/512x512/apps/org.letsconnect-vpn.client.png

%changelog
* Fri May 23 2025 René Neumaier <r.neumaier@mailbox.org> - 4.5.1
- Update to 4.5.1
  * WireGuard: Add support for PresharedKey
  * WireGuard: Fix allow LAN handling with split tunnel Issue: #635
* Tue May 20 2025 René Neumaier <r.neumaier@mailbox.org> - 4.5.0
- Add 'with' operator to reflect 'eduvpn-common' dependencies
* Wed May 14 2025 René Neumaier <r.neumaier@mailbox.org> - 4.5.0
- Specfile changes
  * Add support for multiple python versions
  * Fix 'BuildRequires' incl. usage of macro %%{python_module}
  * Fix 'Requires' package names
  * Change 'build macros'
  * Cosmetic fixes
* Sun Apr 27 2025 René Neumaier <r.neumaier@mailbox.org> - 4.5.0
- Update to 4.5.0
  * Require python3-eduvpn-common >= 3 && < 4
- Changed source URL from GitHub to Codeberg
- See release notes in /usr/share/doc/packages since pre-release
  Version 4.4.99.0 from 2024-12-20
* Sat Aug  3 2024 René Neumaier <r.neumaier@mailbox.org> - 4.4.0
- Update to 4.4.0
  * Require python3-eduvpn-common >= 2.1.0 && < 3.0.0
- Changed 'URL' to official project website
- Added GPG package source verification
* Tue Jun 11 2024 René Neumaier <r.neumaier@mailbox.org> - 4.3.1
- Update to 4.3.1
  * Lots of changes between version 4.2.1 and 4.3.1 please checkout
    the full release notes in docdir (/usr/share/doc/packages)
- Reworked specfile
  * Added better 'letsconnect-client' description
  * setup.py no longer specify 'extra files' added manual routine
  * Default place for package datadir (share) files collides with
    Tumbleweed/%%{python3_sitelib} macro - workaround in %%prep
  * Removed unneeded dependencies
  * python3-eduvpn-common >= 2.0.0 is needed
* Tue Jun  4 2024 René Neumaier <r.neumaier@mailbox.org> - 4.2.1
- Version requirements to python3-eduvpn-common have been adjusted
  and synchronized: 'setup.py' and specfile
* Fri Feb  2 2024 René Neumaier <r.neumaier@mailbox.org> - 4.2.1
- Update to 4.2.1
  * Make the OpenVPN/WireGuard DNS the maximum priority to avoid
    DNS from resolving through other interfaces
* Sun Dec 17 2023 René Neumaier <r.neumaier@mailbox.org> - 4.2.0
- Update to 4.2.0
  * Protocol info has moved to connection info details
  * Log unhandled exceptions
  * Bump eduvpn-common to 1.2.0
  * Remove unused dbus dependency
  * Add upstream changelog to eduvpn-client docdir
  * See full release notes in docdir (/usr/share/doc/packages)
* Tue Dec  5 2023 René Neumaier <r.neumaier@mailbox.org>
- Specfile changes
  * Removed 'pytest-runner', it isn't a dep. in setup.py
  * Inserted %%find_lang for locales
* Mon Dec  4 2023 René Neumaier <r.neumaier@mailbox.org> - 4.1.3
- Initial commit at 4.1.3
  * Reworked Fedora39 spec from https://app.eduvpn.org
  * Attach last recent GitHub changelog as following:
- 4.1.3 (2023-09-01)
  * Bump eduvpn-common to 1.1.2 to further handle endpoint caching
  * Mention eduvpn-common version in the UI
  * Add a version flag to the CLI
- 4.1.2 (2023-08-29)
  * Make sure profile combo indexes are always set correctly when
    ignoring the reconnect dialog
  * Support MTU for WireGuard
  * Bump eduvpn-common to 1.1.1 in order to fix OAuth endpoint
    caching issues
- 4.1.1 (2023-04-20)
  * Fix profile combo in UI not selecting the actual current
    profile
